<?php
/* 
 * To change this template, choose Tools | Templates
 * and open the template in the editor.
 */
class produit extends controller
{
    protected $model;
    protected $produit;
    private $controller = 'produit';
    private $produit_affiche = 50;
    private $auth;

    public function __construct()
    {
        require_once IF_ROOT_PATH . 'core' . DS . 'tva.php';
        
        require_once IF_ROOT_PATH . 'model' . DS . 'produit.php';
        $this->model = new produitModel();
      
        parent::__construct();

        if( isset($this->data['produit_id']))
            $this->produit = $this->model->getById($this->data['produit_id']);

        // Recuperation des droits
        $this->auth = $this->getAuth('auth_produit');
        $this->smarty->assign('auth', $this->auth);
    }

    /**
     * Affiche la liste des produits
     */
    public function index()
    {
        if(isset($this->data['search_send']))
        {
            $search = $this->data['search'];
            $this->produit_affiche = 1000;
            $paramQuery = $this->constructParamQuery($search);
        }



        $this->smarty->assign(array(
            'pagination'    =>  $this->getPagination2(array(
                'total' => $this->model->getNbProduit(),
                'nb_affiche'    =>  $this->produit_affiche,
                'controller'    =>  $this->controller,
             )),
            'categories'    =>  $this->model->getCategorie(true),
            'fournisseurs'  =>  $this->model->getFournisseur(),
            'produits'  =>  $this->model->getAll('',$this->produit_affiche, $this->offset, isset($paramQuery) ? $paramQuery : ''),
        ));

        return $this->smarty->fetch('produit_index.tpl');
    }

    public function constructParamQuery($search)
    {
        $operator = isset($search['strict']) ? ' AND ' : ' OR ' ;
        $paramQuery = '';

       /* if( $search['fournisseur_id'] > 0 )
            $paramQuery .= $operator . ' fournisseur_id =  ' . $search['fournisseur_id'];*/

        if( $search['categorie_id'] > 0)
            $paramQuery .= $operator . ' categorie_id =  ' . $search['categorie_id'];

        if( $search['produit'] != '')
            $paramQuery .= $operator . " tp.nom LIKE '%". $search['produit'] ."%'";

        if( isset($search['stock_alerte']))
            $paramQuery .= $operator . " stock <= stock_alerte";

        if( isset($search['stock_critique']))
            $paramQuery .= $operator . " stock <= stock_critique";

        $paramQuery .= " ";

        return $paramQuery;
    }


    /**
     * Affiche la fiche du produit
     * @return <mixed> code html de la page
     */
    public function fiche()
    {
        if($this->produit == '') redirect(URL_SITE . 'index.php?c=produit');
        
        $this->smarty->assign(array(
            'produit' => $this->produit,
            'tva'   =>  $GLOBALS['tva'],
            'fournisseurs'  =>  $this->model->getAll(PREFIX . 'fournisseur'),                           // Recupere la liste pour le formulaire de saisie
            'produitFournisseur'    =>  $this->model->getProduitFournisseur($this->produit['id']),      // Recupere la liste des liens entre produit et fournisseurs
            'sorties'   =>  $this->model->getSortie($this->produit['id'], 50),                          // Recupere la listes des sorties de stocks
            'entrees'   =>  $this->model->getEntree($this->produit['id'], 50),
        ));

        return $this->smarty->fetch('produit_fiche.tpl');
    }

    public function ajout()
    {
        if($this->auth['ajout'] != 1 && $_SESSION['utilisateur']['admin'] != 1) redirect(URL_SITE . 'index.php?c=produit');

        $this->smarty->assign(array(
            'categories' => $this->model->getCategorie(true),
            'tva'   =>  $GLOBALS['tva'],
        ));
        return $this->smarty->fetch('produit_ajout.tpl');
    }

    public function edit()
    {
        if($this->auth['modif'] != 1 && $_SESSION['utilisateur']['admin'] != 1) redirect(URL_SITE . 'index.php?c=produit');      // Verification droit access
        if($this->produit == '') redirect(URL_SITE . 'index.php?c=produit');                                            // Verification que l edition du produit porte sur un produit existant

        $this->smarty->assign(array(
            'produit'   =>  $this->produit,
            'categories' => $this->model->getCategorie(true),
            'tva'   =>  $GLOBALS['tva'],
        ));
        return $this->smarty->fetch('produit_edit.tpl');
    }

    public function send()
    {
        $GLOBALS['session']->checkCsrfPost();

        $this->produit = $this->data['produit'];

        if($this->produit['nom'] == '') redirect(URL_SITE . 'index.php?c=produit&error=no_name');

        if( isset($this->data['produit_add']) )
        {
            if($_SESSION['utilisateur']['admin'] != 1 && $this->auth['ajout'] != 1) redirect(URL_SITE . 'index.php?c=produit');
            
            $this->model->add($this->produit, PREFIX . 'produit');
            return redirect(URL_SITE . 'index.php?c=produit&a=fiche&produit_id='. $GLOBALS['db']->LastInsertId(), 3 , $GLOBALS['lang']['Produit_ajoute']);
        }

        if( isset($this->data['produit_edit']) )
        {
            if($_SESSION['utilisateur']['admin'] != 1 && $this->auth['modif'] != 1) redirect(URL_SITE . 'index.php?c=produit');
            $this->model->update($this->produit, PREFIX . 'produit');
            return redirect(URL_SITE . 'index.php?c=produit&a=fiche&produit_id='. $this->produit['id'], 3 , $GLOBALS['lang']['Produit_modifie']);
        }
    }

    public function delete()
    {
        if($_SESSION['utilisateur']['admin'] != 1 && $this->auth['del'] != 1) redirect(URL_SITE . 'index.php?c=produit');
        $GLOBALS['session']->checkCsrfGet();
        if($this->produit == '') redirect(URL_SITE . 'index.php?c=produit');

        $this->model->delete($this->produit['id'], PREFIX . 'produit');
        $this->model->delete_produit_link($this->produit['id']);

        return redirect(URL_SITE . 'index.php?c=produit', 3 , $GLOBALS['lang']['Produit_supprime']);
    }

    public function produit_add_fournisseur()
    {
        $GLOBALS['session']->checkCsrfPost();

        $this->model->add($this->data['fournisseur'], PREFIX . 'produit_fournisseur');
        return '<script language="javascript" type="text/javascript">window.top.window.reloadTabFournisseur();</script>';
    }

    /**
     * Supprime le lien entre fournisseur et produit
     * @return <mixed> retourne le tableau fournisseur
     */
    public function produit_delete_fournisseur()
    {
        $GLOBALS['session']->checkCsrfGet();            // Verification du jeton
        if( !isset($this->data['pfid']) ) return false; // Verification id pass
        if( !isset($this->data['produit_id']) ) return false;   // Verification id produit
        
        $this->model->delete($this->data['pfid'], PREFIX . 'produit_fournisseur');  // Supression de la base

        return $this->reloadTabFournisseur();   // Retourne le tableau

    }

    /**
     *  Recharge l onglet fournisseur dans la fiche du produit.
     * @return <mixed>
     */
    public function reloadTabFournisseur()
    {
        $this->smarty->assign('produitFournisseur', $this->model->getProduitFournisseur($this->data['produit_id']));
        return $this->smarty->fetch('produit_liste_fournisseur.tpl');
    }

    /**
     * Recharge le tableau des entrees
     * @return <type>
     */
    public function reloadTabEntree()
    {
        $this->smarty->assign('entrees', $this->model->getEntree($this->produit['id'], 50));
        return $this->smarty->fetch('produit_fiche_liste_entree.tpl');
    }

    /**
     * Recharge le tableau des sorties
     * @return <type>
     */
    public function reloadTabSortie()
    {
        $this->smarty->assign('sorties', $this->model->getSortie($this->produit['id'], 50));
        return $this->smarty->fetch('produit_fiche_liste_sortie.tpl');
    }

    /**
     * Verifie si la reference du produit est deja dans la base
     * @return <bool>
     */
    public function checkReference()
    {
        return $this->model->getNumberRow(PREFIX . 'produit', " WHERE reference = '". $this->data['reference'] ."'");
    }

    public function addEntre()
    {
        $produit = array('id' => $this->produit['id'], 'stock' => $this->produit['stock']);     // Creation d un array pour la mise a jour des stocks
        $produit['stock'] = $produit['stock'] + $this->data['entree']['quantite'];              // Calcul du nouveau stock
        $this->model->add($this->data['entree'], PREFIX . 'produit_entre');                     // Enregistrement de la sortie
        $this->model->update($produit, PREFIX . 'produit');                                     // Mise  jour du produit
        return '<script language="javascript" type="text/javascript">window.top.window.reloadTabEntree('. $produit['stock'] .');</script>';
    }

    public function addSortie()
    {
        $produit = array('id' => $this->produit['id'], 'stock' => $this->produit['stock']);     // Creation d un array pour la mise a jour des stocks
        $produit['stock'] = $produit['stock'] - $this->data['sortie']['quantite'];              // Calcul du nouveau stock
        $this->model->add($this->data['sortie'], PREFIX . 'produit_sortie');                    // Enregistrement de la sortie
        $this->model->update($produit, PREFIX . 'produit');                                     // Mise  jour du produit
        if($this->produit['stock_alerte'] >= $produit['stock'])
            $this->sendAlerte($produit['stock']);
        echo '<script language="javascript" type="text/javascript">window.top.window.reloadTabSortie('. $produit['stock'] .');</script>';        
    }

    public function sendAlerte($stock)
    {
        $user_alerte = $this->model->getUserAlerte();  // Recuperation des utilisateurs recevant les alertes.

        // Construction pour enregistrement dans la base
        $data_alerte = array(
            'titre' =>  $GLOBALS['lang']['Alerte_stock_pour_le_produit'] . ' ' . $this->produit['nom'],
            'description'   => $this->produit['stock_critique'] >= $stock ? sprintf($GLOBALS['lang']['Message_alerte_stock_critique'], $this->produit['nom'], $stock, $this->produit['stock_alerte'], $this->produit['stock_critique'], URL_SITE . 'index.php?c=produit&a=fiche&produit_id='. $this->produit['id']) : sprintf($GLOBALS['lang']['Message_alerte_stock_alerte'], $this->produit['nom'], $stock, $this->produit['stock_alerte'], $this->produit['stock_critique'], URL_SITE . 'index.php?c=produit&a=fiche&produit_id='. $this->produit['id']),
            'controller'    =>  'produit',
            'controller_id' =>  $this->produit['id']
        );

        // Construction liste destinataire
        $destinataire = array();
        foreach($user_alerte as $u)
        {
            if($u['email'] != '')
                $destinataire[''. $u['email']  .''] = $u['email'];
        }

        // Construction pour l envoie email
        $email_alerte = array(
            'sujet' => $GLOBALS['lang']['Alerte_stock_pour_le_produit'] . ' ' . $this->produit['nom'],
            'message'   =>  $this->produit['stock_critique'] >= $stock ? sprintf($GLOBALS['lang']['Message_alerte_stock_critique'], $this->produit['nom'], $stock, $this->produit['stock_alerte'], $this->produit['stock_critique'], URL_SITE . 'index.php?c=produit&a=fiche&produit_id='. $this->produit['id']) : sprintf($GLOBALS['lang']['Message_alerte_stock_alerte'], $this->produit['nom'], $stock, $this->produit['stock_alerte'], $this->produit['stock_critique'], URL_SITE . 'index.php?c=produit&a=fiche&produit_id='. $this->produit['id']),
            'message_html'  =>  '',
            'expediteur'    =>  $GLOBALS['setting']['email'],
            'expediteur_email'  => $GLOBALS['setting']['email'],
            'destinataire'  =>  $destinataire,
        );
        
        $this->model->sendAlerte($data_alerte, $user_alerte);   // Enregistrement des alertes dans la base

        // Envoie des email
        //require_once IF_ROOT_PATH . 'core'. DS . 'functions_email.php';
        //sendEmail($email_alerte);
        
    }


    /**
     * Annule une entre en stocks
     * @return <integer> Stock mise a jour
     */
    public function cancelSortie()
    {
        $GLOBALS['session']->checkCsrfGet();                                                            // Verification du jeton de securite
        
        $produit = array('id' => $this->produit['id'], 'stock' => $this->produit['stock']);             // Creation d un array pour la mise a jour des stocks
        $produit['stock'] = $produit['stock'] + $this->data['sortie_quantite'];                         // Calcul du nouveau stock
        $this->model->delete($this->data['sortie_id'], PREFIX . 'produit_sortie');                      // Supression de la base
        $this->model->update($produit, PREFIX . 'produit');                                             // Mise  jour du produit

        return $produit['stock'];                                                                       // Retourne le nouveau stock
    }

    public function deleteSortie()
    {
        $GLOBALS['session']->checkCsrfGet();                                                            // Verification du jeton de securite

        $this->model->delete($this->data['sortie_id'], PREFIX . 'produit_sortie');                      // Supression de la base

        return $this->produit['stock'];                                                                 // retourne le stock
    }

    /**
     * Annule l entre de la base de donnes et remet les stocks a jours
     * @return <type>
     */
    public function cancelEntree()
    {
        $GLOBALS['session']->checkCsrfGet();

        $produit = array('id' => $this->produit['id'], 'stock' => $this->produit['stock']);             // Creation d un array pour la mise a jour des stocks
        $produit['stock'] = $produit['stock'] - $this->data['sortie_quantite'];                         // Calcul du nouveau stock
        $this->model->delete($this->data['entree_id'], PREFIX . 'produit_entre');                      // Supression de la base
        $this->model->update($produit, PREFIX . 'produit');                                             // Mise  jour du produit

        return $produit['stock'];                                                                       // Retourne le nouveau stock
    }

    /**
     * Supprime l entre de la base de donnes
     * @return <type>
     */
    public function deleteEntree()
    {
        $GLOBALS['session']->checkCsrfGet();                                                            // Verification du jeton de securite

        $this->model->delete($this->data['entree_id'], PREFIX . 'produit_entre');                      // Supression de la base

        return $this->produit['stock'];                                                                 // retourne le stock
    }

    public function ajaxAutoSearch()
    {
        $resultat = '';
        if( isset($this->data['queryString']) )
        {
                $queryString  =  $this->data['queryString'];

                if( strlen($queryString) > 0)
                {
                    $query = "SELECT id, reference, nom FROM ". PREFIX ."produit WHERE (nom LIKE '%$queryString%' OR reference LIKE '%$queryString%') LIMIT 10";

                        // Execution requete
                        $req = $GLOBALS['db']->query($query);
                        $res = $req->fetchAll();

                        if( count($res) > 0 )
                        {
                            $this->smarty->assign('produits',$res);
                            return $this->smarty->fetch('produit_ajaxAutoSearch.tpl');
                        }
                        else
                            return $resultat;
                }
                else
                    return $resultat;
        }
        else
                return $resultat;
}

}
?>
