<?php

class modelClient extends model
{
    public function getById($client_id)
    {
        $req = $GLOBALS['db']->prepare("SELECT tc.*, tcc.titre AS categorie FROM ". PREFIX ."client tc LEFT JOIN ". PREFIX ."client_categorie tcc ON tc.categorie_id = tcc.id WHERE tc.id = :client_id LIMIT 1");
        $req->bindParam('client_id', $client_id, PDO::PARAM_INT);
        $req->execute();
        $res = $req->fetch();
        $req->closeCursor();
        return $res;
    }
    
    /**
     * @desc Retourne la liste des clients
     * @limit nombre max de resultat a retourner
     * @offset parametre pour pagination
     * @orderby si tri specifique demande
     * */
    public function getClient($limit = 50, $offset = '', $orderby = '')
    {
        // Construction requete
        $Query = "SELECT * FROM ". PREFIX ."client";
        
        // Construction du tie si demande
        if($orderby != '')
        {
            $Query .= " ORDER BY ". $orderby;
        }
        
        // Determination de la limite
        $Query .= " LIMIT ". $limit;
        
        // offset pour pagination
        if($offset != '')
        {
            $Query .= " OFFSET ". $offset;
        }
        
        // On prepare la requete
        $req = $GLOBALS['db']->prepare($Query);
        //Execution
        $req->execute();
        //On retourne les resultats
        return $req->fetchAll();        
    }
    
    /**
     * @desc Sauvegarde les donnes reu du formulaire
     * @data Contient les donnes du formulaire
     * */
    public function save($data)
    {
        if( $GLOBALS['db']->exec( CreateQueryInsert($data, PREFIX.'client')) )
        {
            return true;
        }
        else
        {
            return false;
        }
    }
    
    /**
     * @desc Sauvegarde les modifcations du client
     * @data array contenant les donnes du formulaire
     * */
    public function edit($data)
    {
        if( $GLOBALS['db']->exec( CreateQueryUpdate($data, PREFIX.'client', " id = ". $data['id'])) )
        {
            return true;
        }
        else
        {
            return false;
        }
    }
    
    public function getAuth()
    {
        // Test si auth definie
        if( controller::getNumberRow(PREFIX . 'auth_client', " WHERE user_id = ". $_SESSION['utilisateur_id'] ." ") == 0 )
        {
            $GLOBALS['db']->exec("INSERT INTO ". PREFIX ."auth_client (user_id) VALUES (". $_SESSION['utilisateur_id'] .")");
        }
        
        // Recuperation des droits.        
        $req = $GLOBALS['db']->prepare("SELECT * FROM ". PREFIX ."auth_client WHERE user_id = :user LIMIT 1");
        $req->bindParam('user', $_SESSION['utilisateur_id'], PDO::PARAM_INT);
        $req->execute();
        $res = $req->fetch();
        $req->closeCursor();
        return $res;
    }
    
    public function getChampSup()
    {
        $req = $GLOBALS['db']->prepare("SELECT label, name_in_form FROM ". PREFIX ."formulaire_champ WHERE formulaire_name = 'client' ");
        $req->execute();
        return $req->fetchAll();
    }
    
    public function updateCpt($client_id)
    {
        $req = $GLOBALS['db']->prepare('UPDATE '. PREFIX .'client SET view = view + 1 WHERE id = :client_id');
        $req->bindParam('client_id', $client_id, PDO::PARAM_INT);
        $req->execute();
        
        $this->addLog($client_id, 'Consultation_fiche');
    }
    
    /**
     * */
     public function addLog($client_id, $action)
     {
        $req = $GLOBALS['db']->exec("INSERT INTO ". PREFIX ."client_log (client_id, user_id, action) value (". $client_id .", ". $_SESSION['utilisateur_id'] .", '". $action ."')");
     }
     
     public function getHistorique($client_id)
     {
        $req = $GLOBALS['db']->prepare("SELECT action, date_action, tu.identifiant AS utilisateur FROM ". PREFIX ."client_log tcl LEFT JOIN ". PREFIX ."utilisateur tu ON tcl.user_id = tu.id WHERE client_id = :client_id ORDER BY date_action DESC LIMIT 30 ");
        $req->bindParam('client_id', $client_id, PDO::PARAM_INT);
        $req->execute();
        return $req->fetchAll();
     }
     
     public function delete($client_id)
     {
		// Supression du client
        $req = $GLOBALS['db']->prepare("DELETE FROM ". PREFIX ."client WHERE id = :client_id");
        $req->bindParam('client_id', $client_id, PDO::PARAM_INT);
        $req->execute();
        
		// Supression des logs
        $req = $GLOBALS['db']->prepare("DELETE FROM ". PREFIX ."client_log WHERE client_id = :client_id");
        $req->bindParam('client_id', $client_id, PDO::PARAM_INT);
        $req->execute();
		
		// Suppression des commentaire
		$req = $GLOBALS['db']->prepare("DELETE FROM ". PREFIX ."client_commentaire WHERE client_id = :client_id");
        $req->bindParam('client_id', $client_id, PDO::PARAM_INT);
        $req->execute();
		
		// Supression des rendez vous
		$req = $GLOBALS['db']->prepare("DELETE FROM ". PREFIX ."client_rdv WHERE client_id = :client_id");
		$req->bindParam('client_id', $client_id, PDO::PARAM_INT);
        $req->execute();
		
		// Supression des fichiers
		if( $f = getFileInDir(IF_ROOT_PATH . 'upload' . DS . 'client' . DS . $client_id) )
		{
			foreach($f as $k => $v)
			{
				@unlink(IF_ROOT_PATH . 'upload' . DS . 'client' . DS . $client_id . DS . $v);
			}
			
			@rmdir(IF_ROOT_PATH . 'upload' . DS . 'client' . DS . $client_id);
		}
     }
     
     public function getNbClient()
     {
        return controller::getNumberRow(PREFIX . 'client', '');
     }
	 
	 public function saveCommentaire($data)
	 {
		$req = $GLOBALS['db']->prepare("INSERT INTO ". PREFIX ."client_commentaire (commentaire, client_id ,user_id) VALUES (:commentaire, :client_id ,:user_id)");
		$req->bindParam('commentaire', $data['commentaire'], PDO::PARAM_STR);
		$req->bindParam('client_id', $data['client_id'], PDO::PARAM_INT);
		$req->bindParam('user_id', $_SESSION['utilisateur_id'], PDO::PARAM_INT);
		$req->execute();
		
		$this->addLog($data['client_id'], 'Commentaire_ajoute');
	 }
	 
	 public function getCommentaireByClient($client)
	 {
		$req = $GLOBALS['db']->prepare("SELECT tcc.id, commentaire, tcc.date_ajout, tu.identifiant AS utilisateur_ajout FROM ". PREFIX ."client_commentaire tcc INNER JOIN ". PREFIX ."utilisateur tu ON tcc.user_id = tu.id WHERE client_id = :client_id ORDER BY date_ajout DESC");
		$req->bindParam('client_id', $client, PDO::PARAM_INT);
		$req->execute();
		return $req->fetchAll();
	 }
	 
	 public function commentaireDelete($data)
	 {
		$req = $GLOBALS['db']->prepare("DELETE FROM ". PREFIX ."client_commentaire WHERE id = :commentaire_id AND client_id = :client_id LIMIT 1");
		$req->bindParam('commentaire_id', $data['commentaire_id'], PDO::PARAM_INT);
		$req->bindParam('client_id', $data['client_id'], PDO::PARAM_INT);
		$req->execute();
	 }
	 
	 public function rendezvousSave($data)
	 {
		$req = $GLOBALS['db']->exec( CreateQueryInsert($data, PREFIX . 'client_rdv') );
	 }
	 
	 public function rendezvousDelete($rendezvous_id)
	 {
		$req = $GLOBALS['db']->prepare("DELETE FROM ". PREFIX ."client_rdv WHERE id = :rendezvous_id LIMIT 1");
		$req->bindParam('rendezvous_id', $rendezvous_id, PDO::PARAM_INT);
		$req->execute();
	 }
	 
	 public function getRendezvousByClient($client_id)
	 {
		$req = $GLOBALS['db']->prepare("SELECT tcr.id, sujet_rdv, date_rdv, identifiant FROM ". PREFIX ."client_rdv tcr INNER JOIN ". PREFIX ."utilisateur tu ON tcr.user_id = tu.id WHERE client_id = :client_id ORDER BY date_rdv DESC");
		$req->bindParam('client_id', $client_id, PDO::PARAM_INT);
		$req->execute();
		return $req->fetchAll();
	 }
     
     /**
      * @desc Recupere la liste des tickers
      * @param $client_id integer
      * @return liste des tickets.
      * */
     public function getTicketByClient($client_id)
     {
        $req = $GLOBALS['db']->prepare('
            SELECT tt.id, titre, priorite, statut, tt.date_ajout, tu.identifiant, ttc.nom as categorie, user_attrib 
			FROM '. PREFIX .'ticket tt 
			LEFT JOIN '. PREFIX .'utilisateur tu ON tt.user_id = tu.id 
			LEFT JOIN '. PREFIX .'ticket_categorie ttc ON tt.categorie_id = ttc.id
            WHERE client_id = :client_id
            ORDER BY date_ajout DESC');
            
        $req->bindParam('client_id', $client_id, PDO::PARAM_INT);
        $req->execute();
        return $req->fetchAll();
     }
}
?>